import styles from './index.less';
import { useModel } from 'umi';
import React, { useState, useEffect, useRef } from 'react';
import { Carousel, Button } from 'antd';
import { useWindowSize } from '@/utils/windowsize';
import { doFetch } from '@/utils/doFetch';
import { useRequest } from 'ahooks';
import { Palette } from 'color-thief-react';
import { CaretRightOutlined } from '@ant-design/icons';

// match： 与客户端页面 props 中的 match 保持一致，有当前路由的相关数据。
// isServer：是否为服务端在执行该方法。
// route：当前路由对象
// history：history 对象

function spArr(arr, num) {
  let newArr = [];
  for (let i = 0; i < arr.length; ) {
    newArr.push(arr.slice(i, (i += num)));
  }
  return newArr;
}

const transitiongroup = (ifs) => {
  return {
    0: {
      transform: ifs ? 'scale(1)' : 'scale(0.5)',
      opacity: ifs ? 1 : 0.1,
    },
    1: {
      transform: ifs ? 'translateX(0)' : 'translateX(-100px)',
      opacity: ifs ? 1 : 0.1,
    },
  };
};

const production = {
  r: [
    {
      title: 'MES智能制造管理系统',
      desc: '南高智能制造管理系统(MES) 是应用于生产制造车间的生产信息化管理系统。',
      detail: '',
    },
    {
      title: 'WMS智能仓储管理系统',
      desc: '南高智能仓储管理系统(WMS)是应用于仓储作业管理的仓储信息化管理系统。',
      detail: '',
    },
    {
      title: 'EMS设备运维管理系统',
      desc: '设备管理系统提供公有云、私有云两种部署方式，可为企业提供定制化开发服务，投入少、见效快。 ',
      detail: '',
    },
    {
      title: 'IOT数据采集系统',
      desc: '组合各种物联网硬件采集多种数据，通过南高工业互联网平台,可上实现数据监测和设备控制。',
      detail: '',
    },
    {
      title: 'PLM产品生命周期管理系统',
      desc: '依托领先产品技术及解决方案，为企业提供了一整套全方位的数字化产品生命周期管理平台。',
      detail: '',
    },
    {
      title: 'PDM产品数据管理系统',
      desc: '南高智能仓储管理系统(WMS)是应用于仓储作业管理的仓储信息化管理系统。',
      detail: '',
    },
  ],
  l: [
    {
      title: 'Z系列智能网关',
      desc: '支持西门子（含有OPCUA配件) /FANUC全系列/DELEM65等系列(含有OPCUA配件）等CNC的采集。',
      detail: '',
    },
    {
      title: 'S系列智能网关',
      desc: '包含Z系列基础版本的所有功能，还支持6组0-10v电压型输入传感器的采集。',
      detail: '',
    },
    {
      title: 'C系列智能网关',
      desc: '包含Z系列基础版本的所有功能，以外还支持施耐德、汇川、产电、松下、安川等串口PLC的采集。',
      detail: '',
    },
  ],
};

function IndexPage({ route }) {
  //   const { initialState, loading, error, refresh, setInitialState } =
  //   useModel('@@initialState');

  const cauref = useRef();
  const { width, height } = useWindowSize(); //设备宽高
  const [currindex, setcurrindex] = useState(0);
  const [type, settype] = useState('r');
  const { data } = useRequest(async () => {
    let res = await doFetch({ url: '/indexPic/list' });
    return res?.data?.dataList ?? [];
  });

  //autoplay
  return (
    <div>
      <Carousel
        afterChange={(cur) => {
          setcurrindex(cur);
        }}
      >
        {data?.map((it, i) => {
          return (
            <div
              key={it.picLinkUrl}
              style={{ cursor: it?.picLinkUrl ? 'pointer' : 'default' }}
              onClick={() => {
                it?.picLinkUrl && window.open(it.picLinkUrl);
              }}
            >
              <Palette
                src={it.picUrl}
                colorCount={6}
                crossOrigin="anonymous"
                format="rgbArray"
              >
                {({ data, loading, error }) => {
                  const arr = data ? data[0] : [255, 255, 255];
                  const color = `rgba(${
                    255 - arr[0] > 55 ? 255 : 255 - arr[0]
                  },${255 - arr[1] > 55 ? 255 : 255 - arr[1]}, ${
                    255 - arr[2] > 35 ? 255 : 255 - arr[2]
                  }, 1)`;
                  const shadowcolor = `rgba(${arr[0]},${arr[1]}, ${arr[2]}, 1)`;
                  const curtransition = transitiongroup(currindex == i)[i];
                  return (
                    <div
                      className={styles.banner}
                      key={Math.random()}
                      style={{
                        width,
                        height: (980 / 1920) * width,
                        backgroundImage: `url(${it.picUrl})`,
                      }}
                    >
                      <div className={styles.textcontent}>
                        <h2
                          style={{
                            color: color,
                            textShadow: `0 0 4px ${shadowcolor}`,
                            fontSize: '3.5vw',
                            '--color': color,
                            '--shadowcolor': shadowcolor,
                            transition: 'all 1s',
                            ...curtransition,
                          }}
                        >
                          {it.title}
                        </h2>
                        <p
                          style={{
                            color: color,
                            fontSize: '1.5vw',
                            transition: 'all 1.4s',
                            ...curtransition,
                          }}
                        >
                          {it.subTitle}
                        </p>
                        {it.enableBtn == 1 && (
                          <Button
                            ghost
                            size={
                              width < 780
                                ? 'small'
                                  ? width < 1366
                                  : 'middle'
                                : 'large'
                            }
                            style={{
                              ...curtransition,
                              transition: 'all 1.45s',
                              color,
                              borderColor: color,
                            }}
                            onClick={(e) => {
                              e.stopPropagation();
                              window.open(it.btnLinkUrl);
                            }}
                          >
                            {it.enableBtnName}
                            <CaretRightOutlined />
                          </Button>
                        )}
                      </div>
                    </div>
                  );
                }}
              </Palette>
            </div>
          );
        })}
      </Carousel>
      <div className="section bglights">
        <h2 className="title">核心产品</h2>
        <p className="tabs">
          <span
            style={{
              cursor: 'pointer',
              color: type == 'r' ? '#1890ff' : '#000000',
            }}
            onClick={() => settype('r')}
          >
            工业软件
          </span>
          <span style={{ padding: '0 12px' }}>/</span>
          <span
            style={{
              cursor: 'pointer',
              color: type == 'l' ? '#1890ff' : '#000000',
            }}
            onClick={() => settype('l')}
          >
            智能硬件
          </span>
        </p>
        {type == 'r' && (
          <>
            <div className="iconleft">
              <img
                src={require('@/assets/icon/left.png')}
                alt=""
                onClick={() => {
                  cauref?.current?.prev();
                }}
              />
            </div>
            <div className="iconright">
              <img
                src={require('@/assets/icon/right.png')}
                alt=""
                onClick={() => {
                  cauref?.current?.next();
                }}
              />
            </div>
          </>
        )}

        <div className="slider">
          <Carousel
            ref={cauref}
            dots={{
              className: 'diydots',
            }}
          >
            {spArr(
              production[type].map((it, i) => {
                it.picUrl =
                  type == 'r'
                    ? require(`@/assets/pic${i + 1}.jpg`)
                    : require(`@/assets/l${i + 1}.jpg`);
                return it;
              }),
              width < 500 ? 1 : width < 798 ? 2 : 3,
            ).map((it, i) => {
              return (
                <div key={it.picurl}>
                  <div className="spread">
                    {it.map((item, index) => {
                      return (
                        <div className="proditem" key={item.picUrl}>
                          <img src={item.picUrl} alt="" />
                          <div className="placecontainer"></div>
                          <div className="textcontainer">
                            <h2>{item.title}</h2>
                            <p className="twoline">{item.desc}</p>
                            <Button className="btn">查看详情</Button>
                          </div>
                        </div>
                      );
                    })}
                  </div>
                </div>
              );
            })}
          </Carousel>
        </div>
      </div>
      <div
        className="section"
        style={{
          background: `url(${require('@/assets/notice.jpg')}) no-repeat center`,
          padding: '8vw',
          backgroundSize: 'cover',
        }}
      >
        <div style={{ backgroundColor: 'rgba(0,0,0,0.7)', padding: 36 }}>
          <h2
            className="title"
            style={{ color: '#FFFFFF', marginBottom: '2rem' }}
          >
            公司简介
          </h2>
          <p
            style={{
              width: '66vw',
              display: 'block',
              margin: '0 auto',
              color: '#ffffff',
              fontSize: '0.6rem',
              textAlign: 'center',
              marginBottom: '2rem',
            }}
          >
            江苏南高智能装备创新中心有限公司是由东南大学牵头，联合地方政府和省内高档数控机床及成套装备行业的数家龙头企业共同创立的专注于数控机床及成套装备领域的高新技术企业。汇集信息技术人才，结合数字孪生、机器视觉、AI、5G等新兴技术，帮助制造业企业打造数字化智慧工厂。
          </p>
          <Button
            ghost
            style={{ margin: '0 auto', display: 'block' }}
            size="large"
          >
            查看详情
          </Button>
        </div>
      </div>

      <div
        className="section"
        style={{
          padding: '24px',
        }}
      >
        <h2 className="title">南高优势</h2>
        <p
          className="tabs"
          style={{ display: 'block', width: '66vw', margin: '0 auto' }}
        >
          江苏南高自主申请知识产权逾100项，其中发明专利65个。技术研究团队人数占员工总数87%。公司建立了数据融合与质量科学、AI与智能装备创意设计机床结构动态优化创新设计及数字化、智能化设计与制造等共性技术研发平台.
        </p>
      </div>
    </div>
  );
}

// IndexPage.getInitialProps = async (ctx) => {
//   return await doFetch({url:"/indexPic/list"})
// };

export default IndexPage;
